@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for codebuild service client
 
@@ -10,10 +11,12 @@ Usage::
     client: CodeBuildClient = boto3.client("codebuild")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_codebuild.paginator import (
     DescribeTestCasesPaginator,
     ListBuildsForProjectPaginator,
@@ -517,3 +520,6 @@ class CodeBuildClient:
         """
         [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
